@@ -4,7 +4,7 @@ from .metrics.collector import MetricCollector
 from .metrics.metrics import PrometheusMiddleware
 from .metrics import config
 
-from .loggers.logger import logger
+from .loggers.logger import Logger
 from .loggers.accesslog import _create_logger, AccessLogAtoms
 
 from .utils.singleton import SingletonMeta
