@@ -342,7 +342,33 @@ class PrometheusMiddleware(metaclass=SingletonMeta):
     def add_fastapi_middleware(self):
         # TODO look into this later
         self.app.add_middleware(MetricsRedirect)
-        self.app.mount("/metrics", WSGIMiddleware(make_wsgi_app()))
+
+        if self.is_multiprocessing:
+            clear_multiproc_dir()
+
+            def make_wsgi_multiprocess_app():
+                def app_multiprocess(environ, start_response):
+                    environ["PATH_INFO"] = "/metrics"
+                    registry = CollectorRegistry()
+                    multiprocess.MultiProcessCollector(registry)
+                    data = generate_latest(registry)
+                    status = "200 OK"
+                    response_headers = [
+                        ("Content-type", CONTENT_TYPE_LATEST),
+                        ("Content-Length", str(len(data))),
+                    ]
+                    start_response(status, response_headers)
+                    return iter([data])
+
+                return app_multiprocess
+
+            self.app.mount("/metrics", WSGIMiddleware(make_wsgi_multiprocess_app()))
+
+            # self.app.wsgi_app = DispatcherMiddleware(
+            #     self.app.wsgi_app, {"/metrics": make_wsgi_multiprocess_app()}
+            # )
+        else:
+            self.app.mount("/metrics", WSGIMiddleware(make_wsgi_app()))
 
         def get_path_format(app_routes, path):
             """loop through all endpoint to get parh_format"""
